==> jc-1.4.0.tar.gz: org/dellroad/jc/SearchpathFinder.h <==
// public class org.dellroad.jc.SearchpathFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ebf65e658a770d42 org_dellroad_jc_SearchpathFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_SearchpathFinder_H_
#define _JC_org_dellroad_jc_SearchpathFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_SearchpathFinder$sub_refs	_jc_org_dellroad_jc_SearchpathFinder$sub_refs;
typedef struct _jc_org_dellroad_jc_SearchpathFinder$sub_nonrefs	_jc_org_dellroad_jc_SearchpathFinder$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_SearchpathFinder$refs	_jc_org_dellroad_jc_SearchpathFinder$refs;
typedef struct _jc_org_dellroad_jc_SearchpathFinder$nonrefs	_jc_org_dellroad_jc_SearchpathFinder$nonrefs;
typedef struct _jc_org_dellroad_jc_SearchpathFinder$object	_jc_org_dellroad_jc_SearchpathFinder$object;

typedef struct _jc_org_dellroad_jc_SearchpathFinder$fields_struct	_jc_org_dellroad_jc_SearchpathFinder$fields_struct;
typedef const struct _jc_org_dellroad_jc_SearchpathFinder$vmethods	_jc_org_dellroad_jc_SearchpathFinder$vmethods;
typedef const struct _jc_org_dellroad_jc_SearchpathFinder$vtable	_jc_org_dellroad_jc_SearchpathFinder$vtable;
typedef const struct _jc_org_dellroad_jc_SearchpathFinder$vtype	_jc_org_dellroad_jc_SearchpathFinder$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_SearchpathFinder$fields_struct {
	struct _jc_java_lang_String$object	*fs;
	jchar	ps;
};
extern _jc_org_dellroad_jc_SearchpathFinder$fields_struct _jc_org_dellroad_jc_SearchpathFinder$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_SearchpathFinder$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_SearchpathFinder$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *);
extern _jc_byte_array *_jc_org_dellroad_jc_SearchpathFinder$method$getClassfile$2323c94e9ff74fa5(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *);
extern jlong _jc_org_dellroad_jc_SearchpathFinder$method$getClassfileHash$c7c304d80ea40ac2(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_SearchpathFinder$method$getPath$7dfdcb0b5a7c8226(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *);
extern _jc_object_array *_jc_org_dellroad_jc_SearchpathFinder$method$getPathArray$2077b2e587ec96ba(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *);
extern void _jc_org_dellroad_jc_SearchpathFinder$method$loadCache$d69b57b168547d4a(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$getClassfile$2323c94e9ff74fa5;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$getClassfileHash$c7c304d80ea40ac2;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$getPath$7dfdcb0b5a7c8226;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$getPathArray$2077b2e587ec96ba;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$loadCache$d69b57b168547d4a;

// Static methods
extern void _jc_org_dellroad_jc_SearchpathFinder$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern _jc_object_array *_jc_org_dellroad_jc_SearchpathFinder$method$splitPath$852e5721186cc02a(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_dellroad_jc_SearchpathFinder$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *);
	_jc_byte_array	*(*getClassfile$2323c94e9ff74fa5)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *);
	jlong	(*getClassfileHash$c7c304d80ea40ac2)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*getPath$7dfdcb0b5a7c8226)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *);
	_jc_object_array	*(*getPathArray$2077b2e587ec96ba)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *);
	void	(*loadCache$d69b57b168547d4a)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *);
};

// Vtable
struct _jc_org_dellroad_jc_SearchpathFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_SearchpathFinder$vmethods	org_dellroad_jc_SearchpathFinder;
};

// Vtype
struct _jc_org_dellroad_jc_SearchpathFinder$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_SearchpathFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_SearchpathFinder$sub_refs {
	struct _jc_java_lang_String$object	*path;
	_jc_object_array	*files;
	_jc_object_array	*cache;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_SearchpathFinder$refs {
    _jc_org_dellroad_jc_SearchpathFinder$sub_refs	org_dellroad_jc_SearchpathFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_SearchpathFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_SearchpathFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_SearchpathFinder$sub_nonrefs	org_dellroad_jc_SearchpathFinder;
};

// Object instance structure
struct _jc_org_dellroad_jc_SearchpathFinder$object {
	_jc_org_dellroad_jc_SearchpathFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_SearchpathFinder$vtype	*vtype;
	_jc_org_dellroad_jc_SearchpathFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_SearchpathFinder$vtype _jc_org_dellroad_jc_SearchpathFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_SearchpathFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_SearchpathFinder$class_object;

#endif	/* _JC_org_dellroad_jc_SearchpathFinder_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/SearchpathFinder.h <==
// public class org.dellroad.jc.SearchpathFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ebf65e658a770d42 org_dellroad_jc_SearchpathFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_SearchpathFinder_H_
#define _JC_org_dellroad_jc_SearchpathFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_SearchpathFinder$sub_refs	_jc_org_dellroad_jc_SearchpathFinder$sub_refs;
typedef struct _jc_org_dellroad_jc_SearchpathFinder$sub_nonrefs	_jc_org_dellroad_jc_SearchpathFinder$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_SearchpathFinder$refs	_jc_org_dellroad_jc_SearchpathFinder$refs;
typedef struct _jc_org_dellroad_jc_SearchpathFinder$nonrefs	_jc_org_dellroad_jc_SearchpathFinder$nonrefs;
typedef struct _jc_org_dellroad_jc_SearchpathFinder$object	_jc_org_dellroad_jc_SearchpathFinder$object;

typedef struct _jc_org_dellroad_jc_SearchpathFinder$fields_struct	_jc_org_dellroad_jc_SearchpathFinder$fields_struct;
typedef const struct _jc_org_dellroad_jc_SearchpathFinder$vmethods	_jc_org_dellroad_jc_SearchpathFinder$vmethods;
typedef const struct _jc_org_dellroad_jc_SearchpathFinder$vtable	_jc_org_dellroad_jc_SearchpathFinder$vtable;
typedef const struct _jc_org_dellroad_jc_SearchpathFinder$vtype	_jc_org_dellroad_jc_SearchpathFinder$vtype;

// Class fields structure
struct _jc_org_dellroad_jc_SearchpathFinder$fields_struct {
	struct _jc_java_lang_String$object	*fs;
	jchar	ps;
};
extern _jc_org_dellroad_jc_SearchpathFinder$fields_struct _jc_org_dellroad_jc_SearchpathFinder$class_fields;

// Constructors
extern void _jc_org_dellroad_jc_SearchpathFinder$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_SearchpathFinder$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_org_dellroad_jc_SearchpathFinder$method$getClassfile$2323c94e9ff74fa5(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jlong _jc_org_dellroad_jc_SearchpathFinder$method$getClassfileHash$c7c304d80ea40ac2(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_SearchpathFinder$method$getPath$7dfdcb0b5a7c8226(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_org_dellroad_jc_SearchpathFinder$method$getPathArray$2077b2e587ec96ba(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *) _JC_JCNI_ATTR;
extern void _jc_org_dellroad_jc_SearchpathFinder$method$loadCache$d69b57b168547d4a(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$getClassfile$2323c94e9ff74fa5;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$getClassfileHash$c7c304d80ea40ac2;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$getPath$7dfdcb0b5a7c8226;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$getPathArray$2077b2e587ec96ba;
extern _jc_method _jc_org_dellroad_jc_SearchpathFinder$method_info$loadCache$d69b57b168547d4a;

// Static methods
extern void _jc_org_dellroad_jc_SearchpathFinder$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_org_dellroad_jc_SearchpathFinder$method$splitPath$852e5721186cc02a(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_SearchpathFinder$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getClassfile$2323c94e9ff74fa5)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	jlong	(*getClassfileHash$c7c304d80ea40ac2)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPath$7dfdcb0b5a7c8226)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getPathArray$2077b2e587ec96ba)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *) _JC_JCNI_ATTR;
	void	(*loadCache$d69b57b168547d4a)(_jc_env *, struct _jc_org_dellroad_jc_SearchpathFinder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_SearchpathFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_SearchpathFinder$vmethods	org_dellroad_jc_SearchpathFinder;
};

// Vtype
struct _jc_org_dellroad_jc_SearchpathFinder$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_SearchpathFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_SearchpathFinder$sub_refs {
	struct _jc_java_lang_String$object	*path;
	_jc_object_array	*files;
	_jc_object_array	*cache;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_SearchpathFinder$refs {
    _jc_org_dellroad_jc_SearchpathFinder$sub_refs	org_dellroad_jc_SearchpathFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_SearchpathFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_SearchpathFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_SearchpathFinder$sub_nonrefs	org_dellroad_jc_SearchpathFinder;
};

// Object instance structure
struct _jc_org_dellroad_jc_SearchpathFinder$object {
	_jc_org_dellroad_jc_SearchpathFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_SearchpathFinder$vtype	*vtype;
	_jc_org_dellroad_jc_SearchpathFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_SearchpathFinder$vtype _jc_org_dellroad_jc_SearchpathFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_SearchpathFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_SearchpathFinder$class_object;

#endif	/* _JC_org_dellroad_jc_SearchpathFinder_H_ */
